View Source Sentry.FinchClient (Sentry v12.0.3)

The built-in HTTP client.

This client implements the Sentry.HTTPClient behaviour. It's based on the Finch Elixir HTTP client, which is an optional dependency of this library. If you wish to use another HTTP client, you'll have to implement your own Sentry.HTTPClient. See the documentation for Sentry.HTTPClient for more information. Finch is built on top of NimblePool. If you need to set other pool configuration options, see "Pool Configuration Options" in the Finch documentation for details on the possible map values. finch configuration options