View Source Sentry.LogBatch (Sentry v12.0.3)

A batch of log events to be sent in a single envelope item.

According to the Sentry Logs Protocol, log events are sent in batches within a single envelope item with content type application/vnd.sentry.items.log+json.

Summary

Types

@type t() :: %Sentry.LogBatch{log_events: [Sentry.LogEvent.t()]}