View Source Sentry.MetricBatch (Sentry v13.0.1)

A batch of metric events to be sent in a single envelope item.

According to the Sentry Metrics Protocol, metrics are sent in batches within a single envelope item with content type application/vnd.sentry.items.trace-metric+json.

Summary

Types

@type t() :: %Sentry.MetricBatch{metrics: [Sentry.Metric.t()]}